@@ -1,7 +1,7 @@
 package App::lcpan;
 
 our $DATE = '2015-04-15'; # DATE
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 use 5.010001;
 use strict;
@@ -1361,7 +1361,7 @@ LEFT JOIN dist d1 ON f1.id=d1.file_id
 }
 
 sub _get_prereqs {
-    require Module::CoreList;
+    require Module::CoreList::More;
     require Version::Util;
 
     my ($mod, $dbh, $memory, $level, $max_level, $phase, $rel, $include_core, $plver) = @_;
@@ -1400,8 +1400,8 @@ ORDER BY module");
             next;
         }
 
-        #say "include_core=$include_core, is_core($row->{module}, $row->{version}, $plver)=", Module::CoreList::is_core($row->{module}, $row->{version}, version->parse($plver)->numify);
-        next if !$include_core && Module::CoreList::is_core($row->{module}, $row->{version}, version->parse($plver)->numify);
+        #say "include_core=$include_core, is_core($row->{module}, $row->{version}, $plver)=", Module::CoreList::More->is_still_core($row->{module}, $row->{version}, version->parse($plver)->numify);
+        next if !$include_core && Module::CoreList::More->is_still_core($row->{module}, $row->{version}, version->parse($plver)->numify);
         next unless defined $row->{module}; # BUG? we can encounter case where module is undef
         if (defined $memory->{$row->{module}}) {
             if (Version::Util::version_gt($row->{version}, $memory->{$row->{module}})) {
@@ -1647,7 +1647,7 @@ App::lcpan - Manage your local CPAN mirror
 
 =head1 VERSION
 
-This document describes version 0.18 of App::lcpan (from Perl distribution App-lcpan), released on 2015-04-15.
+This document describes version 0.19 of App::lcpan (from Perl distribution App-lcpan), released on 2015-04-15.
 
 =head1 SYNOPSIS
 
@@ -1767,7 +1767,7 @@ Recurse for a number of levels (-1 means unlimited).
 
 =item * B<module>* => I<str>
 
-=item * B<perl_version> => I<str> (default: "v5.18.4")
+=item * B<perl_version> => I<str> (default: "v5.18.1")
 
 Set base Perl version for determining core modules.
 
